@@ -297,9 +297,9 @@ const WizardFooter = ({activeStep, activeSubStep, stepCount, subStepCounts, isDe
         ),
         nextBtnClasses = classNames(
             "btn", "btn-primary", "wizard-pf-next",
-            { "hidden": (!hasSubSteps && isLastStep) || (hasSubSteps && isLastStep && isLastSubStep) },
+            { "hidden": (!hasSubSteps && isLastStep) || (hasSubSteps && isLastStep && isLastSubStep) }
         ), cancelBtnClasses = classNames(
-            "btn", "btn-default", "btn-cancel", "wizard-pf-cancel", "wizard-pf-dismiss",
+            "btn", "btn-default", "btn-cancel", "wizard-pf-cancel", "wizard-pf-dismiss"
         );
 
     let customActionBtnClasses = "hidden";
@@ -341,7 +341,7 @@ const WizardFooter = ({activeStep, activeSubStep, stepCount, subStepCounts, isDe
 
     return (
         <div className="modal-footer wizard-pf-footer">
-            <button type="button" className={cancelBtnClasses} onClick={cancel} data-dismiss={dataDismissValue}
+            <button type="button" className={cancelBtnClasses} onClick={cancel} data-dismiss="modal"
                     aria-hidden="true">
                 Cancel
             </button>
